@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2004 Free Software Foundation
+   Copyright (C) 2001-2013 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+            Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -55,10 +56,9 @@ static NSDictionary  *dict = nil;
       // Setting up the dictionary needed for registration!
 
       // Objective C Class
-      descr = [NSString stringWithString:
-	@"Generic Objective-C class.\n\n"
-	@"This is a plain subclass of NSObject which includes"
-	@" only Foundation.h."];
+      descr = @"Generic Objective-C class.\n\n"
+		@"This is a plain subclass of NSObject which includes"
+		@" only Foundation.h.";
       template = [bundle pathForResource:@"class" ofType:@"template"];
       classDict = [NSDictionary dictionaryWithObjectsAndKeys:
 	PCClasses, @"ProjectKey",
@@ -67,10 +67,9 @@ static NSDictionary  *dict = nil;
 	nil];
 
       // Objective C Header
-      descr = [NSString stringWithString:
-	@"Generic Objective-C header.\n\n"
-	@"This is a plain interface subclassing NSObject."
-	@" The file includes Foundation.h"];
+      descr = @"Generic Objective-C header.\n\n"
+		@"This is a plain interface subclassing NSObject."
+		@" The file includes Foundation.h";
       template = [bundle pathForResource:@"header" ofType:@"template"];
       headerDict =[NSDictionary dictionaryWithObjectsAndKeys:
         PCHeaders,@"ProjectKey",
@@ -79,9 +78,8 @@ static NSDictionary  *dict = nil;
         nil];
 
       // C File
-      descr = [NSString stringWithString:
-	@"Generic ANSI-C implementation file.\n\n"
-	@"This file contains no Objective-C dependency in any form."];
+      descr = @"Generic ANSI-C implementation file.\n\n"
+		@"This file contains no Objective-C dependency in any form.";
       template = [bundle pathForResource:@"cfile" ofType:@"template"];
       ccDict = [NSDictionary dictionaryWithObjectsAndKeys:
         PCOtherSources,@"ProjectKey",
@@ -90,9 +88,8 @@ static NSDictionary  *dict = nil;
         nil];
 
       // C Header
-      descr = [NSString stringWithString:
-	@"Generic ANSI-C header.\n\n"
-	@"This file contains no Objective-C dependency in any form."];
+      descr = @"Generic ANSI-C header.\n\n"
+		@"This file contains no Objective-C dependency in any form.";
       template = [bundle pathForResource:@"cheader" ofType:@"template"];
       chDict = [NSDictionary dictionaryWithObjectsAndKeys:
         PCHeaders,@"ProjectKey",
@@ -101,10 +98,9 @@ static NSDictionary  *dict = nil;
         nil];
 
       // Objective C Protocol
-      descr = [NSString stringWithString:
-	@"Generic Objective-C protocol.\n\n"
-	@"This is common Objective-C protocol, comparable"
-	@" i.e. to a Java interface."];
+      descr = @"Generic Objective-C protocol.\n\n"
+		@"This is common Objective-C protocol, comparable"
+		@" i.e. to a Java interface.";
       template = [bundle pathForResource:@"protocol" ofType:@"template"];
       protocolDict = [NSDictionary dictionaryWithObjectsAndKeys:
         PCHeaders,@"ProjectKey",
@@ -113,9 +109,8 @@ static NSDictionary  *dict = nil;
         nil];
 
       // GSMarkup
-      descr = [NSString stringWithString:
-	@"Generic GSMarkup File.\n\n"
-	@"This is the interface description of GNUstep Renaissance."];
+      descr = @"Generic GSMarkup File.\n\n"
+		@"This is the interface description of GNUstep Renaissance.";
       template = [bundle pathForResource:@"gsmarkup" ofType:@"template"];
       gsmarkupDict =[NSDictionary dictionaryWithObjectsAndKeys:
         PCGSMarkupFiles,@"ProjectKey",
@@ -255,11 +250,13 @@ static NSDictionary  *dict = nil;
       key = [fileType objectForKey:@"ProjectKey"];
       template = [fileType objectForKey:@"TemplateFile"];
 
-      [pcfm copyFile:template toFile:newFile];
-      [self replaceTagsInFileAtPath:newFile withProject:aProject];
-      [aProject addFiles:[NSArray arrayWithObject:newFile]
-   		  forKey:key
-		  notify:YES];
+      if ([pcfm copyFile:template toFile:newFile])
+        {
+          [self replaceTagsInFileAtPath:newFile withProject:aProject];
+          [aProject addFiles:[NSArray arrayWithObject:newFile]
+                      forKey:key
+                      notify:YES];
+        }
     }
 
   // Notify the browser!
@@ -281,7 +278,13 @@ static NSDictionary  *dict = nil;
   NSString *fn = [aFile stringByDeletingPathExtension];
   NSRange  subRange;
 
+#ifdef WIN32 	 
+  file = [[NSMutableString stringWithContentsOfFile: newFile 	 
+					   encoding: NSUTF8StringEncoding 	 
+					      error: NULL] retain]; 	 
+#else
   file = [[NSMutableString stringWithContentsOfFile:newFile] retain];
+#endif
 
   while ((subRange = [file rangeOfString:@"$FULLFILENAME$"]).length)
     {
@@ -324,8 +327,16 @@ static NSDictionary  *dict = nil;
 	withString:[[NSNumber numberWithInt:year] stringValue]];
     }
 
+#ifdef WIN32 	 
+  [file writeToFile: newFile 	 
+	 atomically: YES 	 
+	   encoding: NSUTF8StringEncoding 	 
+	      error: NULL]; 	 
+#else
   [file writeToFile:newFile atomically:YES];
-  [file autorelease];
+#endif
+
+  [file release];
 }
 
 @end
@@ -446,9 +457,6 @@ static NSDictionary  *dict = nil;
   NSFileManager *fm = [NSFileManager defaultManager];
   BOOL          complementary;
 
-/*  NSLog(@"PCFileCreator: [createFile] %@ in category: %@", 
-	fileName, projectKey);*/
-
   path = [[activeProject projectPath] stringByAppendingPathComponent:fileName];
   // Create file
   if (path) 
