@@ -330,6 +330,41 @@ static PCFileManager *_mgr = nil;
   return YES;
 }
 
+// ===========================================================================
+// ==== Find Executable
+// Tries to find the first matching executable tool fromt he given, nil-terminated
+// list. Returns the full path for it.
+// ===========================================================================
+- (NSString*) findExecutableToolFrom: (NSArray*)candidates
+{
+  NSFileManager	*manager;
+  NSEnumerator	*pathEnumerator;
+  NSString	*directory;
+
+  manager = [NSFileManager defaultManager];
+  pathEnumerator = [NSSearchPathForDirectoriesInDomains(NSDeveloperDirectory, NSAllDomainsMask, YES) objectEnumerator];
+
+  while (nil != (directory = [pathEnumerator nextObject]))
+    {
+      NSEnumerator *candidateEnumerator = [candidates objectEnumerator];
+      NSString     *candidate;
+
+      while (nil != (candidate = [candidateEnumerator nextObject]))
+        {
+          NSString *path = [directory stringByAppendingPathComponent: candidate];
+
+          NSLog(@"final candidate path is: %@", path);
+          
+          if ([manager isExecutableFileAtPath: path])
+	    {
+	      return path;
+            }
+        }
+    }
+  return nil;
+}
+
+
 @end
 
 @implementation PCFileManager (UInterface)
@@ -608,9 +643,11 @@ static PCFileManager *_mgr = nil;
 {
   NSFileHandle *fh;
   NSData       *data;
-  unsigned int i, n;
-  const char   *buf;
-  unsigned int printable;
+  NSUInteger i, printable = 0;
+  NSString *content;
+  NSCharacterSet *alpha = [NSCharacterSet alphanumericCharacterSet];
+  NSCharacterSet *spaces = [NSCharacterSet whitespaceAndNewlineCharacterSet];
+  NSCharacterSet *marks = [NSCharacterSet punctuationCharacterSet];
 
   fh = [NSFileHandle fileHandleForReadingAtPath:filename];
   if (fh == nil)
@@ -624,16 +661,18 @@ static PCFileManager *_mgr = nil;
       return YES;
     }
 
-  buf = [data bytes];
-  for (i = printable = 0, n = [data length]; i < n; i++)
+  content = [NSString stringWithContentsOfFile: filename];
+  for (i = 0; i < [content length]; i++)
     {
-      if (isprint((int)(unsigned char)buf[i]) || isspace((int)(unsigned char)buf[i]))
+      if ([alpha characterIsMember: [content characterAtIndex: i]] ||
+	  [spaces characterIsMember: [content characterAtIndex: i]] ||
+	  [marks characterIsMember: [content characterAtIndex: i]])
 	{
 	  printable++;
 	}
     }
 
-  return (((double) printable / n) > 0.9);
+  return (((double) printable / i) > 0.9);
 }
 
 - (NSArray *)filesWithExtension:(NSString *)extension
