@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2004 Free Software Foundation
+   Copyright (C) 2000-2014 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -121,7 +121,7 @@ enum {
     NSMakeSize([stdOut frame].size.width, 1e7)];
 
   // Font
-  string  = [NSString stringWithString:@"=== Launcher ready ==="];
+  string  = @"=== Launcher ready ===";
   attributedString = 
     [[NSAttributedString alloc] initWithString:string 
                                     attributes:textAttributes];
@@ -260,7 +260,7 @@ enum {
   gdbPath = [[[project projectManager] prefController] stringForKey:Debugger];
   if (gdbPath == nil)
     {
-      gdbPath = [NSString stringWithString:@"/usr/bin/gdb"];
+      gdbPath = @"/usr/bin/gdb";
     }
 
   if ([fm isExecutableFileAtPath:gdbPath] == NO)
@@ -290,6 +290,7 @@ enum {
   NSPipe          *logPipe;
   NSPipe          *errorPipe;
   NSString        *executablePath;
+  NSFileManager   *fm;
 
   executablePath = [NSMutableString stringWithString:[project projectPath]];
 
@@ -299,7 +300,6 @@ enum {
       NSString *prjType;
 
       prjType = [project projectTypeName];
-      NSLog(@"project is executable");
       if ([prjType isEqualToString: @"Application"])
 	{
           /* MyApplication.app/MyApplication */
@@ -326,7 +326,29 @@ enum {
       [runButton setState:NSOffState];
       return;
     }
+
+#ifdef  __MINGW__
+  /* On windows we need to check the .exe file */
+  if ([[executablePath pathExtension] length] == 0)
+    {
+      executablePath = [executablePath stringByAppendingPathExtension: @"exe"];
+    }
+#endif
+
   NSLog(@"executable launch path: %@", executablePath);
+
+  /* now check if the executable does exist. Perhaps make failed */
+  fm = [NSFileManager defaultManager];
+  if (![fm isExecutableFileAtPath:executablePath])
+    {
+      NSRunAlertPanel(@"Run",
+		      @"The project does not have an executable",
+		      @"Close", nil, nil, nil);
+      [runButton setState:NSOffState];
+      return;
+    }
+  
+
   // [makeTask isRunning] doesn't work here.
   // "waitpid 7045, result -1, error No child processes" is printed.
   if (launchTask)
@@ -377,6 +399,7 @@ enum {
   [debugButton setEnabled:NO];
 
   _isRunning = YES;
+  _isErrorRunning = YES;
   RELEASE(args);
 }
 
@@ -387,7 +410,16 @@ enum {
       return;
     }
 
-  [NOTIFICATION_CENTER removeObserver:self];
+  [NOTIFICATION_CENTER removeObserver: self
+				 name: NSTaskDidTerminateNotification
+			       object: launchTask];
+
+  // Wait if there are data available.
+  if (_isRunning || _isErrorRunning)
+    {
+      [[NSRunLoop currentRunLoop] runMode: NSDefaultRunLoopMode
+			       beforeDate: [NSDate distantFuture]];
+    }
 
   [runButton setState:NSOffState];
   [debugButton setState:NSOffState];
@@ -397,7 +429,6 @@ enum {
 
   RELEASE(launchTask);
   launchTask = nil;
-  _isRunning = NO;
   _isDebugging = NO;
 
 }
@@ -406,24 +437,38 @@ enum {
 {
   NSData *data;
 
-  if ((data = [readHandle availableData]))
+  if ((data = [readHandle availableData]) && [data length] > 0)
     {
       [self logData:data error:NO];
+      [readHandle waitForDataInBackgroundAndNotifyForModes:nil];
     }
+  else
+    {
+      [NOTIFICATION_CENTER removeObserver: self 
+			             name: NSFileHandleDataAvailableNotification
+			           object: readHandle];
 
-  [readHandle waitForDataInBackgroundAndNotifyForModes:nil];
+      _isRunning = NO;
+    }
 }
 
 - (void)logErrOut:(NSNotification *)aNotif
 {
   NSData *data;
    
-  if ((data = [errorReadHandle availableData]))
+  if ((data = [errorReadHandle availableData]) && [data length] > 0)
     {
       [self logData:data error:YES];
+      [errorReadHandle waitForDataInBackgroundAndNotifyForModes:nil];
+    }
+  else
+    {
+      [NOTIFICATION_CENTER removeObserver: self 
+			             name: NSFileHandleDataAvailableNotification
+			           object: errorReadHandle];
+
+      _isErrorRunning = NO;
     }
-                       
-  [errorReadHandle waitForDataInBackgroundAndNotifyForModes:nil];
 }
 
 @end
