@@ -451,7 +451,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   if ([projectClassName isEqualToString:@"PCGormProj"] ||
       [projectClassName isEqualToString:@"PCAppProj"])
     {
-      projectTypeName = [NSString stringWithString:@"Application"];
+      projectTypeName = @"Application";
       projectClassName = [projectTypes objectForKey:projectTypeName];
     }
 
@@ -553,6 +553,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString     *projectFileType = nil;
   PCProject    *project = nil;
   NSDictionary *wap = nil;
+  NSString     *projectPathToSave;
 
   // Check project path for invalid characters
   if ([aPath rangeOfString: @" "].location != NSNotFound ||
@@ -591,7 +592,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
       BOOL                isDir = NO;
       BOOL                exists = NO;
       NSArray             *tempList;
-
+ 
       exists = [[NSFileManager defaultManager] fileExistsAtPath:aPath 
 						    isDirectory:&isDir];
       if (!exists)
@@ -599,6 +600,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	  return nil;
 	}
 
+      projectPathToSave = projectPath;
       if (isDir)
 	{
 	  if ([projectFileType isEqualToString:@"pcproj"] == NO)
@@ -611,6 +613,10 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 		  aPath = [tempList objectAtIndex:0];
 		}
 	    }
+	  else
+	    {
+	      projectPathToSave = aPath;
+	    }
 	  aPath = [aPath stringByAppendingPathComponent:@"PC.project"];
 	  projectFile = [NSMutableDictionary dictionaryWithContentsOfFile:aPath];
 	}
@@ -697,7 +703,10 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	  [[project projectWindow] makeKeyAndOrderFront:self];
 	  [self setActiveProject: project];
 	}
+      PCLogStatus(self, @"Saved opened Document as %@", projectPathToSave);
+      [[NSDocumentController sharedDocumentController] noteNewRecentDocumentURL: [NSURL fileURLWithPath:projectPathToSave]];
     }
+
   
   return project;
 }
@@ -796,21 +805,27 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   return project;
 }
 
-- (void)newProject
+- (void)newProject: (id)sender
 {
-  NSArray   *files;
+  NSArray   *files, *types = nil;
   NSString  *filePath;
   NSString  *projectType;
   PCProject *project;
 
+
   [self createProjectTypeAccessaryView];
   
-  files = [fileManager filesOfTypes:nil
+  files = [fileManager filesOfTypes:types
 			  operation:PCSaveFileOperation
 			   multiple:NO
 			      title:@"New Project"
 			    accView:projectTypeAccessaryView];
   filePath = [files objectAtIndex:0];
+
+#ifdef WIN32
+  filePath = [filePath stringByDeletingPathExtension];
+#endif
+
   if (filePath != nil) 
     {
       if ([filePath rangeOfString: @" "].location != NSNotFound ||
@@ -939,12 +954,12 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	  project = [activeProject superProject];
 	  [self setActiveProject:project];
 	}
-      removeString = [NSString stringWithString:@"Remove subprojects..."];
+      removeString = @"Remove subprojects...";
       directory = [project dirForCategoryKey:categoryKey];
     }
   else
     {
-      removeString = [NSString stringWithString:@"Remove files..."];
+      removeString = @"Remove files...";
       project = activeProject;
     }
 
