@@ -49,9 +49,9 @@
   rect = NSMakeRect(0,0,windowWidth,320);
 
   _window = [[NSWindow alloc] initWithContentRect:rect
-                                        styleMask:style
-                                          backing:NSBackingStoreBuffered
-                                            defer:YES];
+					styleMask:style
+					  backing:NSBackingStoreBuffered
+					    defer:YES];
   [_window setReleasedWhenClosed:NO];
   [_window setMinSize:NSMakeSize(512,320)];
   [_window setDelegate:self];
@@ -137,6 +137,7 @@
   [ev setMinSize:NSMakeSize(0, 0)];
   [ev setMaxSize:NSMakeSize(1e7, 1e7)];
   [ev setRichText:YES];
+  [ev setUsesFindPanel: YES];
   [ev setVerticallyResizable:YES];
   [ev setHorizontallyResizable:NO];
   [ev setAutoresizingMask:NSViewWidthSizable|NSViewHeightSizable];
@@ -987,32 +988,10 @@
     }
 }
 
-- (void)scrollToLineNumber:(unsigned int)lineNumber
+- (void)scrollToLineNumber:(NSUInteger)lineNumber
 {
-  unsigned int offset;
-  unsigned int i;
-  NSString     *line;
-  NSEnumerator *e;
-  NSArray      *lines;
-  NSRange      range;
-
-  lines = [[_intEditorView string] componentsSeparatedByString: @"\n"];
-  e = [lines objectEnumerator];
-
-  for (offset = 0, i = 1;
-       (line = [e nextObject]) != nil && i < lineNumber;
-       i++, offset += [line length] + 1);
-
-  if (line != nil)
-    {
-      range = NSMakeRange(offset, [line length]);
-    }
-  else
-    {
-      range = NSMakeRange([[_intEditorView string] length], 0);
-    }
-  [_intEditorView setSelectedRange:range];
-  [_intEditorView scrollRangeToVisible:range];
+  [_intEditorView goToLineNumber:lineNumber];
+  [_extEditorView goToLineNumber:lineNumber];
 }
 
 @end
@@ -1170,19 +1149,19 @@ static inline BOOL CheckDelimiter(unichar character,
  * @return The location of the delimiter if it is found, or NSNotFound
  *      if it isn't.
  */
-unsigned int FindDelimiterInString(NSString * string,
-                                   unichar delimiter,
-                                   unichar oppositeDelimiter,
-                                   unsigned int startLocation,
-                                   BOOL searchBackwards)
+NSUInteger FindDelimiterInString(NSString * string,
+                                 unichar delimiter,
+                                 unichar oppositeDelimiter,
+                                 NSUInteger startLocation,
+                                 BOOL searchBackwards)
 {
-  unsigned int i;
-  unsigned int length;
-  unichar (*charAtIndex)(id, SEL, unsigned int);
+  NSUInteger i;
+  NSUInteger length;
+  unichar (*charAtIndex)(id, SEL, NSUInteger);
   SEL sel = @selector(characterAtIndex:);
   int nesting = 1;
 
-  charAtIndex = (unichar (*)(id, SEL, unsigned int)) [string
+  charAtIndex = (unichar (*)(id, SEL, NSUInteger)) [string
     methodForSelector: sel];
 
   if (searchBackwards)
@@ -1249,7 +1228,7 @@ unsigned int FindDelimiterInString(NSString * string,
   [textStorage beginEditing];
 
 //  if (isCharacterHighlit)
-  for (i = 0; (highlited_chars[i] != -1 && i < 2); i++)
+  for (i = 0; i < 2 && highlited_chars[i] != -1; i++)
     {
       NSRange       r = NSMakeRange(highlited_chars[i], 1);
 //      NSRange       r = NSMakeRange(highlitCharacterLocation, i);
@@ -1299,11 +1278,11 @@ unsigned int FindDelimiterInString(NSString * string,
   [textStorage endEditing];
 }
 
-- (void)highlightCharacterAt:(unsigned int)location inEditor: (NSTextView *)editorView
+- (void)highlightCharacterAt:(NSUInteger)location inEditor: (NSTextView *)editorView
 {
   int i;
 
-  for (i = 0; highlited_chars[i] != -1; i++) {};
+  for (i = 0; i < 2 && highlited_chars[i] != -1; i++) {};
 
 //  if (isCharacterHighlit == NO)
   if (i < 2)
@@ -1384,7 +1363,7 @@ unsigned int FindDelimiterInString(NSString * string,
       // we're searching for).
       if (CheckDelimiter(c, &oppositeDelimiter, &searchBackwards))
         {
-          unsigned int result;
+          NSUInteger result;
 
           result = FindDelimiterInString(myString,
                                          oppositeDelimiter,
