@@ -1,7 +1,7 @@
 /*
 **  CodeParser.m
 **
-**  Copyright (c) 2003
+**  Copyright (c) 2003-2014
 **
 **  Author: Yen-Ju  <yjchenx@hotmail.com>
 **
@@ -126,8 +126,8 @@ CodeType codeType(unichar *ch)
 
 - (void)parse
 {
-  unsigned int i, start, end;
-  CodeType startType, endType;
+  NSUInteger i, start, end;
+  CodeType startType;
   NSString *out;
   SEL selString = @selector(string:);
   SEL selNumber = @selector(number:);
@@ -140,7 +140,6 @@ CodeType codeType(unichar *ch)
   void (*impInvisible)(id, SEL, unichar); 
   void (*impSymbol)(id, SEL, unichar); 
 
-  NSLog(@"CodeParser begin...");
 
   impString = (void (*)(id, SEL, id))
               [[_handler class] instanceMethodForSelector:selString]; 
@@ -156,12 +155,12 @@ CodeType codeType(unichar *ch)
   start = end = 0;
   startType = codeType(_uchar+start);
 
-  for (i = 1; i < _length+1; i++)
+  for (i = 1; i <= _length; i++)
     {
       end = i;
-      endType = codeType(_uchar+end);
       
-      if ((startType != endType) || (end == _length))
+      /* check for end, but check for end char only if not at end */
+      if ((end == _length) || (startType != codeType(_uchar+end)) )
         {
           /* Check period in number */
           if ((startType == NumberCodeType) && (_uchar[end] == 0x2E))
@@ -179,7 +178,7 @@ CodeType codeType(unichar *ch)
             }
           else if (startType == SpaceAndNewLineCodeType)
             {
-              unsigned int j, jlen = end-start/*[out length]*/;
+              NSUInteger j, jlen = end-start/*[out length]*/;
               for (j = 0; j < jlen; j++)
                 {
 		  (*impSpaceAndNewLine)(_handler, 
@@ -188,7 +187,7 @@ CodeType codeType(unichar *ch)
             }
           else if (startType == SymbolCodeType)
             {
-              unsigned int j, jlen = end-start/*[out length]*/;
+              NSUInteger j, jlen = end-start/*[out length]*/;
               for (j = 0; j < jlen; j++)
                 {
                   (*impSymbol)(_handler, selSymbol, _uchar[start+j]);
@@ -196,17 +195,21 @@ CodeType codeType(unichar *ch)
             }
           else if (startType == InvisibleCodeType)
             {
-              unsigned int j, jlen = end-start/*[out length]*/;
+              NSUInteger j, jlen = end-start/*[out length]*/;
               for (j = 0; j < jlen; j++)
                 {
                   (*impInvisible)(_handler, selInvisible, _uchar[start+j]);
                 }
             }
-          start = i;
-          startType = codeType(_uchar+start);
+          /* if we are at the end, we can getting the last stat char anyway
+             and in any case it would not be valid */
+          if (end != _length)
+            {
+              start = i;
+              startType = codeType(_uchar+start);
+            }
         }
     }
-  NSLog(@"CodeParser end...");
 }
 
 @end
