@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2010 Free Software Foundation
+   Copyright (C) 2001-2012 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -83,7 +83,7 @@
 {
   PCFileManager  *pcfm = [PCFileManager defaultManager];
   NSMutableArray *otherRes = nil;
-  NSString       *oldFile = [NSString stringWithString:@"Info-gnustep.plist"];
+  NSString       *oldFile = @"Info-gnustep.plist";
   NSString       *oldFilePath = nil;
   NSString       *infoFile = nil;
   NSString       *infoFilePath = nil;
@@ -441,7 +441,7 @@
 - (BOOL)writeMakefile
 {
   PCMakefileFactory *mf = [PCMakefileFactory sharedFactory];
-  int               i,count; 
+  NSUInteger        i,count; 
   NSString          *mfl = nil;
   NSData            *mfd = nil;
   NSString          *key = nil;
@@ -484,11 +484,11 @@
     }
   // Remove localized resource files from gathered array
   localizedResources = [projectDict objectForKey:PCLocalizedResources];
-  for (i = [resources count] - 1; i >= 0; i--)
+  for (i = [resources count]; i > 0; i--)
     {
-      if ([localizedResources containsObject:[resources objectAtIndex:i]])
+      if ([localizedResources containsObject:[resources objectAtIndex:i-1]])
 	{
-	  [resources removeObjectAtIndex:i];
+	  [resources removeObjectAtIndex:i-1];
 	}
     }
   [mf appendResources:resources inDir:@"Resources"];
